/*
 * Project name:
     LIN_Receiver (slave)
 * Copyright:
     (c) mikroElektronika, 2008
 * Revision History:
     20080111:
       - initial release;
 * Description:
     This code shows how to use Usart library for communication with
     MCP201 LIN tranceiver. This example works in conjuction with
     LIN_Transmitter(master). During the receive process,
     received data is displayed on PORTB LEDs.
 * Test configuration:
     MCU:             PIC16F877A
     Dev.Board:       EasyPic5
     Oscillator:      HS, 08.000MHz
     Ext. Modules:    LIN extra board on PORTC
     SW:              mikroC v8.0
 * NOTES:
     - LIN extra board must be powered with 6-18V DC connected to INPUT connector.
     - Turn PIC-RC7(Rx), PIC-RC6(Tx) and PIN2(CS) sitches on LIN board On.
     - Disconnect Master Jumper (J1) on LIN board.
 */

void main () {
  PORTB = 0;
  TRISB = 0;
  PORTC.F2 = 0;                   // CS signal is PIN2 on PORTC
  TRISC.F2 = 0;

  Usart_Init(9600);              // initialize Usart module
  Delay_ms(10);
  
  while(1) {
    if ( Usart_Data_Ready() )     // show received data on PORTB
      PORTB = Usart_Read();

    }
}